
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef EKGBUFFER_H
#define EKGBUFFER_H

#include <vector>
#include "EKGdevice.h"
using namespace std;

/**
 * Puffer fr EKG-Daten. Diese Klasse implementiert einen Ringbuffer
 * gegebener Lnge. Die Lnge kann spter mit resize() gendert werden.
 * Leere Felder sind mit 0-Tripeln initialisiert. Als EKGdevice nimmt der
 * Puffer mit input() neue Werte an, wobei der lteste gelscht wird. Mit
 * dem operator[] kann auf die Elemente zugegriffen werden.
 *
 * @author Lars Stollenwerk, November 2002
 */
class EKGbuffer : public EKGdevice
{
  public:
    /** 
     * Erzeugt Ringbuffer mit n Elementen, die mit 0-Tripeln initialisiert
     * sind.
     */
    EKGbuffer( int n );
    /** Kopierkonstruktor */
    EKGbuffer( const EKGbuffer & buf );
    /** destruktor */
    ~EKGbuffer();
    /** 
     * berschrieben aus EKGdevice. Nimmt neue Daten an und lscht ltestes
     * Element.
     */
    virtual void input( float * d ) ;
    /**
     * Greift auf das i-te Element zu. i=0 bezeichnet das lteste Element.
     */
    float* operator[]( int i ) const { return B[i]; }
    /**
     * Gibt die gre des Puffers zurck.
     */
    int size() const { return B.size(); }
    /**
     * ndert die Lnge des Puffers auf n. Eine Verkleinerung lscht die
     * alten Werte, eine Vergrerung fgt in der Vergangenheit 0-Tripel
     * hinzu.
     */
    void resize( unsigned int n );
    /** 
     * Besetzt alle Werte mit Nulltripeln.
     */
    void reset();
  private:
    vector<float*> B;
};



#endif

