
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "EKGlfilter.h"

// ----------------------------------------------------------------------
//
// Implementation EKGdevice
// 
// ----------------------------------------------------------------------


/*
 * Der Tiefpafilter setzt Oversampling ein, damit die Zeitschrittweite
 * nicht zu gro ist.
 */
void EKGlfilter::input( float * d )
{
  if ( ! enable ) { EKGfilter::input(d); return; }
  float m;
  for ( int i = 0; i < 3; i++ )
  {
    // Zeitschritte im Oversampling
    m = ( d[i] - oldd[i] ) / oversampling;
    for ( int k = 1; k <= oversampling; k++ )
    {
      La[i] += EKG_TimeStep / oversampling * LA[i];
      LA[i] += LL / oversampling * ( oldd[i] + k * m - La[i] ) 
             - LK / oversampling * LA[i];
    }
    // Ausgang
    d[i] = La[i];
  }
  // Daten an nchstes Gert weitergeben. 
  EKGfilter::input( d );
}


// ----------------------------------------------------------------------
//
// public Methoden
// 
// ----------------------------------------------------------------------



/*
 * Frequenz fr Tiefpafilter setzen
 */
float EKGlfilter::setLFreq( float x )
{
  float old = getLFreq();
  float omega = 2 * M_PI * x;
  const float d = 1;
  float K = d * omega;
  float L = omega * omega;
  LK = EKG_TimeStep * K;
  LL = EKG_TimeStep * L;
  return old;
}


