
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003, 2011 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "gEKGFilterDialog.h"

// Konstruktor
gEKGFilterDialog::gEKGFilterDialog() : 
    OKButton( "OK" ),
    AButton( "Apply" ),
    CButton( "Cancel" ),
    LowCheck( "Lowpass Filter" ),
    HighCheck( "Highpass Filter" ),
    LowLabel( "Frequency [Hz]: ", 0, 0.5 ),
    HighLabel( "Time Constant [s]: ", 0, 0.5 ),
    bBox( Gtk::BUTTONBOX_EDGE, 10 ),
    table( 5, 2, false )
{
  // Init Spinbuttons
  LowSpin = manage( new Gtk::SpinButton( 
    *manage( new Gtk::Adjustment( 25, 1, 100, 1, 10, 0 ) ), 0, 1 ) );
  HighSpin = manage( new Gtk::SpinButton( 
    *manage( new Gtk::Adjustment( 0.5, EKG_TimeStep, 10, 0.1, 1, 0 ) ), 0, 1 ) );
   // Aussehen oben
  Gtk::VBox * top = get_vbox();
  table.attach( LowCheck,  0, 2, 0, 1 );
  table.attach( LowLabel,  0, 1, 1, 2 );
  table.attach( *LowSpin,   1, 2, 1, 2, 
                (Gtk::FILL|Gtk::EXPAND), (Gtk::FILL|Gtk::EXPAND), 0, 4 );
  table.attach( separator, 0, 2, 2, 3 );
  table.attach( HighCheck, 0, 2, 3, 4 );
  table.attach( HighLabel, 0, 1, 4, 5 );
  table.attach( *HighSpin,  1, 2, 4, 5,
                (Gtk::FILL|Gtk::EXPAND), (Gtk::FILL|Gtk::EXPAND), 0, 4 );
  top->pack_start( table, false, false, 0 );
  // Aussehen unten
  Gtk::ButtonBox * bottom = get_action_area();
  bBox.pack_start( OKButton );
  bBox.pack_start( AButton );
  bBox.pack_start( CButton );
  bottom->pack_start( bBox );
  // Aussehen allgemein
  set_wmclass( "EKG", "EKG" );
  set_title( "Filter Settings" );
  // TODO set_policy( false, false, true );
  set_border_width( 5 );
  // Alle zeigen, damit die Gre bekannt ist
  LowCheck.show();
  HighCheck.show();
  LowSpin->show();
  HighSpin->show();
  LowLabel.show();
  HighLabel.show();
  separator.show();
  OKButton.show();
  AButton.show();
  CButton.show();
  bBox.show();
  table.show();
  // Event Handler
  OKButton.signal_clicked().connect( 
    mem_fun( *this, & gEKGFilterDialog::buttonCallback ) );
  CButton.signal_clicked().connect( 
    mem_fun( *this, & gEKGFilterDialog::buttonCallback ) );
  signal_key_press_event().connect( 
    mem_fun( *this, & gEKGFilterDialog::keyCallback ) );
}




// Ist-Werte setzen
void gEKGFilterDialog::setValues( 
     bool low, float lowVal, bool high, float highVal )
{
  LowSpin->set_value( lowVal );
  HighSpin->set_value( highVal );
  LowCheck.set_active( low );
  HighCheck.set_active( high );
}


//
// private Methoden
//


// Tastendrcke
gint gEKGFilterDialog::keyCallback( GdkEventKey * e )
{
  switch ( e->keyval )
  {
    case 0xff1b : // escape
      CButton.clicked();
      return true;
  }
  return false;
}

