
/*
 * This file is part of EKG/gEKG, a software package to record EKG.
 * Copyright  2003, 2011 Lars Stollenwerk
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation; either version 2 of the License, or (at your
 * option) any later version.  
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#include "gEKGfreq.h"
#include "heart_bg.xpm"
#include "heart_sm.xpm"

/* Konstruktor */
gEKGfreq::gEKGfreq() : hBox(false,0), Pulse("Pulse"), Hcount(0)
{
  // Bilder initialisieren
  Heart_bg = Gdk::Pixbuf::create_from_xpm_data( heart_bg_xpm );
  Heart_sm = Gdk::Pixbuf::create_from_xpm_data( heart_sm_xpm );
  Heart.set( Heart_sm );
  // Aussehen
  frame.set_shadow_type( Gtk::SHADOW_ETCHED_IN );
  add( frame );
  frame.add( hBox );
  hBox.pack_start( Pulse, false, false, 2 );
  hBox.pack_end( Heart, false, false, 2 );
  // Pipe zur Prozekommunikation
  if ( 0 != pipe( Pipe ) ) 
    throw string("gEKGfreq::gEKGfreq() : Can't open pipe.");
  Glib::signal_io().connect( sigc::mem_fun(*this, &gEKGfreq::drawRealtime), 
                             Pipe[0], Glib::IO_IN );
}


/* Hcount herunterzhlen */
void gEKGfreq::input( float * d )
{
  EKGfreq::input( d );
  if ( Hcount == 0 ) return; 
  Hcount--;
  if ( Hcount != 0 ) return;
  const int i = -1; // -1 in pipe = Herz aus
  if ( psize != write( Pipe[1], &i, psize ) )
    throw string("gEKGfreq::input() : Can't write psize bytes to pipe.");
}

/* kleines Herz zeigen */
void gEKGfreq::reset()
{
  Heart.set( Heart_sm );
}

// ----------------------------------------------------------------------
//
// private Methoden
// 
// ----------------------------------------------------------------------

/* Pusfrequenz verarbeiten */
void gEKGfreq::handleQRS()
{
  EKGfreq::handleQRS();
  Hcount = static_cast<int>( Htime / EKG_TimeStep );
  if ( psize != write( Pipe[1], &freq, psize ) )
    throw string("gEKGfreq::handleQRS() : Can't write psize bytes to pipe.");
}



/* Aktualisieren der Anzeige */
bool gEKGfreq::drawRealtime( Glib::IOCondition )
{
  // Daten von Pipe holen
  int f;
  if ( psize != read( Pipe[0], &f, psize ) )
    cerr << "gEKGfreq::drawRealtime() : Can't get psize bytes." << endl;
  if ( f < 0 ) // Herz aus
  {
    Heart.set( Heart_sm );
  }
  else // Label aktualisieren, Herz an
  {
    ostringstream os;
    os << f << ends;
    Pulse.set_text( os.str() );
    Heart.set( Heart_bg );
  }
  return true;
}


